summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--jstests/auth/mongos_cache_invalidation.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/auth/mongos_cache_invalidation.js b/jstests/auth/mongos_cache_invalidation.js
index 27f470338cb..e36445cac5e 100644
--- a/jstests/auth/mongos_cache_invalidation.js
+++ b/jstests/auth/mongos_cache_invalidation.js
@@ -61,7 +61,7 @@ db3.auth('spencer', 'pwd');
* At this point we have 3 handles to the "test" database, each of which are on connections to
* different mongoses. "db1", "db2", and "db3" are all auth'd as spencer@test and will be used
* to verify that user and role data changes get propaged to their mongoses.
* "db2" is connected to a mongos with a 5 second user cache invalidation interval,
* while "db3" is connected to a mongos with a 10 minute cache invalidation interval.
*/
@@ -201,12 +201,12 @@ db3.auth('spencer', 'pwd');
// s0/db1 should update its cache instantly
assert.commandFailedWithCode(db1.foo.runCommand("collStats"), authzErrorCode);
// s1/db2 should update its cache in 5 seconds.
assert.soon(
function() {
return db2.foo.runCommand("collStats").code == authzErrorCode;
},
- "Mongos did not update its user cache after 5 seconds",
+ "Mongos did not update its user cache after 10 seconds",
6 * 1000); // Give an extra 1 second to avoid races
// We manually invalidate the cache on s2/db3.
@@ -61,7 +61,7 @@ db3.auth('spencer', 'pwd');
* different mongoses. "db1", "db2", and "db3" are all auth'd as spencer@test and will be used
* to verify that user and role data changes get propaged to their mongoses.
- * "db2" is connected to a mongos with a 5 second user cache invalidation interval,
+ * "db2" is connected to a mongos with a 10 second user cache invalidation interval,
* while "db3" is connected to a mongos with a 10 minute cache invalidation interval.
*/
@@ -201,12 +201,12 @@ db3.auth('spencer', 'pwd');
// s0/db1 should update its cache instantly
assert.commandFailedWithCode(db1.foo.runCommand("collStats"), authzErrorCode);
- // s1/db2 should update its cache in 5 seconds.
+ // s1/db2 should update its cache in 10 seconds.
assert.soon(
function() {